@@ -118,7 +118,6 @@ const char *ciphers = auto_ciphers;
 int verifydepth = 1;
 const char *dhfile = auto_dhfile;
 int rsalen = SSL_RSA_LEN;
-char *keypass = 0;
 
 int pi[2];
 int po[2];
@@ -657,7 +656,7 @@ int main(int argc,char * const *argv)
   unsigned long u;
  
   who = argv[0];
-  while ((opt = getoptb(argc,(char **)argv,"dDvqQhHrRUXx:y:t:T:u:g:l:b:B:c:pPoO1346I:EeSsaAf:w:K:zZ")) != opteof)
+  while ((opt = getoptb(argc,argv,"dDvqQhHrRUXx:y:t:T:u:g:l:b:B:c:pPoO1346I:EeSsaAf:w:zZ")) != opteof)
     switch(opt) {
       case 'b': scan_ulong(optarg,&backlog); break;
       case 'c': scan_ulong(optarg,&limit); break;
@@ -686,7 +685,6 @@ int main(int argc,char * const *argv)
       case 'g': scan_ulong(optarg,&gid); break;
       case 'l': localhost = optarg; break;
       case 'I': netif = socket_getifidx(optarg); break;
-      case 'K': keypass = optarg; break;
       case '1': flag1 = 1; break;
       case '3': flag3 = 1; break;
       case '4': ipflag = 1; break;
