@@ -102,7 +102,7 @@ static stralloc addresses;
 unsigned long limit = 40;
 unsigned long numchildren = 0;
 unsigned long ipchildren = 0;
-unsigned long maxconip = 0;
+unsigned long maxconip = 40;
 
 char bspace[16];
 buffer bo;
@@ -182,7 +182,6 @@ const char *ciphers = auto_ciphers;
 int verifydepth = 1;
 const char *dhfile = auto_dhfile;
 int rsalen = SSL_RSA_LEN;
-char *keypass = 0;
 
 char * const *prog;
 
@@ -256,11 +255,13 @@ void found(char *data,unsigned int datalen)
         if (data[1 + split] == '=') {
           data[1 + split] = 0;
           env(data + 1,data + 1 + split + 1);
+
           if (!str_diff(data + 1,"MAXCONIP")) {
             scan_ulong(data + 1 + split + 1,&maxconip);
             if (limit && maxconip > limit) maxconip = limit;
             if (ipchildren >= maxconip) flagdeny = 2;
           }
+
         }
         break;
     }
@@ -743,10 +744,10 @@ int main(int argc,char * const *argv)
   int t;
   int ipflag = 0;
 
-  while ((opt = getoptb(argc,(char **)argv,"1346dDvVqQhHrRUXx:y:t:T:u:g:l:b:B:c:K:pPoOIEeSsw:nNzZm")) != opteof)
+  while ((opt = getoptb(argc,argv,"1346dDvVqQhHrRUXx:y:t:T:u:g:l:b:B:c:pPoOIEeSsw:nNzZm")) != opteof)
     switch (opt) {
       case 'b': scan_ulong(optarg,&backlog); break;
-      case 'c': scan_ulong(optarg,&limit); break;
+      case 'c': scan_ulong(optarg,&limit); maxconip = limit; break;
       case 'X': flagallownorules = 1; break;
       case 'x': fnrules = optarg; break;
       case 'y': fniprules = optarg; break;
@@ -774,7 +775,6 @@ int main(int argc,char * const *argv)
       case 'g': scan_ulong(optarg,&gid); break;
       case 'I': netif = socket_getifidx(optarg); break;
       case 'l': localhost = optarg; break;
-      case 'K': keypass = optarg; break;
       case '1': flag1 = 1; break;
       case '3': flag3 = 1; break;
       case '4': ipflag = 1; break;
@@ -817,7 +817,6 @@ int main(int argc,char * const *argv)
   }
 
   if ((x = env_get("MAXCONIP"))) { scan_ulong(x,&u); maxconip = u; }
-  if (limit && maxconip > limit) maxconip = limit;
   if (!child_readyplus(&children,limit)) drop_nomem();
 
   if ((x = env_get("VERIFYDEPTH"))) { scan_ulong(x,&u); verifydepth = u; }
@@ -911,6 +910,13 @@ int main(int argc,char * const *argv)
     buffer_puts(&bo,localipstr);
     buffer_puts(&bo," : ");
     buffer_puts(&bo,localportstr);
+    buffer_puts(&bo," [");
+    strnum[fmt_ulong(strnum,limit)] = 0;
+    buffer_puts(&bo,strnum);
+    buffer_puts(&bo,"/"); 
+    strnum[fmt_ulong(strnum,maxconip)] = 0;
+    buffer_puts(&bo,strnum);
+    buffer_puts(&bo,"]");
     buffer_puts(&bo,"\n");
     buffer_flush(&bo);
   }
